@@ -10,5 +10,6 @@ from .fedavg import FedAvg
 from .feddyn import FedDyn
 from .fednova import FedNova
 from .fedprox import FedProx
+from .utils import serial_aggregation
 
-__all__ = ["FedAvg", "AdaBest", "FedDyn", "FedNova", "FedProx"]
+__all__ = ["FedAvg", "AdaBest", "FedDyn", "FedNova", "FedProx", "serial_aggregation"]
