@@ -153,7 +153,7 @@ from .utils import validate_score
     "--criterion",
     type=tuple,
     cls=OptionEatAll,
-    default=("CrossEntropyLoss", "log_freq:50"),
+    default=("CrossEntropyScore", "log_freq:50"),
     show_default=True,
     help="loss function to use (defined under fedsim.losses).",
 )
